FileWriter

Struct FileWriter 

pub struct FileWriter {
    pub json_format: bool,
    /* private fields */
}

Fields

json_format: bool

Implementations

Source

impl FileWriter

pub fn new( trader_id: String, instance_id: String, file_config: FileWriterConfig, fileout_level: LevelFilter, clear_log_file: bool, sync_on_flush: bool, ) -> Option<Self>

Creates a new FileWriter instance.

pub fn flush_buffer(&mut self) -> Result<()>

Flushes the userspace file buffer to the OS.

Errors

Returns an error if the underlying file buffer cannot be flushed.

pub fn sync_to_disk(&mut self) -> Result<()>

Requests that flushed file data is synchronized to durable storage.

Errors

Returns an error if the operating system cannot sync the file to disk.

pub fn flush_and_sync(&mut self) -> Result<()>

Flushes buffered file data and then syncs it to disk.

Errors

Returns an error if either flushing the file buffer or syncing the file to disk fails.

pub fn flush_and_sync_logged(&mut self)

Flushes and syncs while preserving the existing logging-on-error behavior.